pub async fn google_callback(
__arg0: State<UnifiedAppState>,
__arg1: Query<GoogleCallbackQuery>,
) -> ResponseExpand description
GET /auth/google/callback?code=&state=&error= This endpoint is hit by the system browser after Google redirects back. Returns an HTML page (shown in the system browser, not the Tauri WebView).