pub async fn memory_cleanup(
__arg0: State<Arc<SharedState>>,
__arg1: Json<MemoryCleanupRequest>,
) -> Result<impl IntoResponse, ApiError>Expand description
Clean up old memory data within specified time bounds
pub async fn memory_cleanup(
__arg0: State<Arc<SharedState>>,
__arg1: Json<MemoryCleanupRequest>,
) -> Result<impl IntoResponse, ApiError>Clean up old memory data within specified time bounds