pub async fn refresh_models(
__arg0: State<UnifiedAppState>,
__arg1: Json<RefreshModelsRequest>,
) -> Result<impl IntoResponse, StatusCode>Expand description
Refresh the dynamic model catalog from remote sources (OpenRouter, Hugging Face).
pub async fn refresh_models(
__arg0: State<UnifiedAppState>,
__arg1: Json<RefreshModelsRequest>,
) -> Result<impl IntoResponse, StatusCode>Refresh the dynamic model catalog from remote sources (OpenRouter, Hugging Face).