Module analyzer

Module analyzer 

Hardware Analyzer

Enhanced hardware detection and profiling for engine compatibility analysis. Extends the existing platform detection with detailed capability assessment.

Structs

EngineRecommendation
Engine recommendation with priority
GPUInfo
Information about available GPUs
HardwareAnalyzer
Analyzes hardware capabilities for engine compatibility
HardwareProfile
Detailed hardware profile for engine compatibility analysis
PerformanceEstimate
Performance estimates for different engine types
SystemInfo
General system information