Module migration

Module migration 

Database migration system

Structs

MigrationManager
Manages database schema migrations

Functions

get_database_stats
Get database statistics from a connection This is safe to call even with a locked connection since it only performs read queries
get_database_stats_from_path
Get database statistics with connection creation Useful when you don’t have an existing connection
run_maintenance
Run database maintenance tasks