pub fn get_database_stats_from_path(db_path: &Path) -> Result<DatabaseStats>Expand description
Get database statistics with connection creation Useful when you don’t have an existing connection
pub fn get_database_stats_from_path(db_path: &Path) -> Result<DatabaseStats>Get database statistics with connection creation Useful when you don’t have an existing connection