pub struct SessionSummariesStore { /* private fields */ }Implementations
Sourceimpl SessionSummariesStore
impl SessionSummariesStore
pub fn new(pool: Arc<Pool<SqliteConnectionManager>>) -> Self
Sourcepub fn upsert(
&self,
session_id: &str,
summary_text: &str,
token_count: i32,
total_message_count: i32,
) -> Result<()>
pub fn upsert( &self, session_id: &str, summary_text: &str, token_count: i32, total_message_count: i32, ) -> Result<()>
Replace the session’s summary with an updated one.
Uses INSERT OR REPLACE so there is always exactly one row per session.
clear_count is incremented by fetching the current value first.
Sourcepub fn get(&self, session_id: &str) -> Result<Option<SessionSummary>>
pub fn get(&self, session_id: &str) -> Result<Option<SessionSummary>>
Retrieve the single summary for a session, if one exists.
Sourcepub fn delete_for_session(&self, session_id: &str) -> Result<usize>
pub fn delete_for_session(&self, session_id: &str) -> Result<usize>
Delete the summary for a session (used during full session cleanup).