pub struct ModelDownloader { /* private fields */ }Expand description
Model downloader service
Implementations
Sourceimpl ModelDownloader
impl ModelDownloader
pub fn new(storage: Arc<ModelStorage>) -> Self
Sourcepub async fn download_model(
&self,
model_info: ModelInfo,
source: DownloadSource,
existing_download_id: Option<String>,
hf_token: Option<String>,
) -> Result<String>
pub async fn download_model( &self, model_info: ModelInfo, source: DownloadSource, existing_download_id: Option<String>, hf_token: Option<String>, ) -> Result<String>
Download a model from the specified source
If existing_download_id is provided, uses that for progress tracking instead of creating a new one
If hf_token is provided, it will be used for HuggingFace authentication
Sourcepub async fn save_model_metadata(
&self,
model_info: &ModelInfo,
source: &DownloadSource,
) -> Result<()>
pub async fn save_model_metadata( &self, model_info: &ModelInfo, source: &DownloadSource, ) -> Result<()>
Save model metadata after successful download
Sourcepub fn progress_tracker(&self) -> &Arc<ProgressTracker>
pub fn progress_tracker(&self) -> &Arc<ProgressTracker>
Get reference to progress tracker
Sourcepub async fn cancel_download(&self, download_id: &str) -> bool
pub async fn cancel_download(&self, download_id: &str) -> bool
Cancel an ongoing download