pub struct HardwareCapabilities {
pub platform: Platform,
pub architecture: HardwareArchitecture,
pub has_cuda: bool,
pub has_metal: bool,
pub has_vulkan: bool,
}Fields
platform: Platformarchitecture: HardwareArchitecturehas_cuda: boolhas_metal: boolhas_vulkan: boolImplementations
Sourceimpl HardwareCapabilities
impl HardwareCapabilities
Sourcepub fn get_runtime_binary_path(&self) -> Option<PathBuf>
pub fn get_runtime_binary_path(&self) -> Option<PathBuf>
Get the appropriate runtime binary path based on platform and hardware.
Directory naming uses the exact capitalisation as stored on disk
(Windows, MacOS, Linux) to match what config.rs expects and
what is present in the repo’s Resources/bin/ tree.