pub struct UnifiedAppState {
pub proxy: AppState,
pub admin: AdminState,
pub llm_engine: Arc<LLMEngine>,
}Fields
proxy: AppStateadmin: AdminStatellm_engine: Arc<LLMEngine>Trait Implementations
Sourceimpl Clone for UnifiedAppState
impl Clone for UnifiedAppState
Sourcefn clone(&self) -> UnifiedAppState
fn clone(&self) -> UnifiedAppState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl FromRef<UnifiedAppState> for AdminState
impl FromRef<UnifiedAppState> for AdminState
Sourcefn from_ref(state: &UnifiedAppState) -> Self
fn from_ref(state: &UnifiedAppState) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<UnifiedAppState> for AppState
impl FromRef<UnifiedAppState> for AppState
Sourcefn from_ref(state: &UnifiedAppState) -> Self
fn from_ref(state: &UnifiedAppState) -> Self
Converts to this type from a reference to the input type.
Sourceimpl FromRef<UnifiedAppState> for Arc<LLMEngine>
impl FromRef<UnifiedAppState> for Arc<LLMEngine>
Sourcefn from_ref(state: &UnifiedAppState) -> Self
fn from_ref(state: &UnifiedAppState) -> Self
Converts to this type from a reference to the input type.