Context worker thread implementation
Handles conversation context optimization and management in a dedicated thread.
Context worker thread implementation
Handles conversation context optimization and management in a dedicated thread.