pub struct EngineManager {
pub registry: Arc<RwLock<EngineRegistry>>,
pub downloader: Arc<EngineDownloader>,
pub analyzer: Arc<HardwareAnalyzer>,
pub hardware_capabilities: HardwareCapabilities,
}Expand description
Main engine management service
Fields
registry: Arc<RwLock<EngineRegistry>>downloader: Arc<EngineDownloader>analyzer: Arc<HardwareAnalyzer>hardware_capabilities: HardwareCapabilitiesImplementations
Sourceimpl EngineManager
impl EngineManager
pub fn new() -> Result<Self>
Sourcepub async fn initialize(&self, _cfg: &Config) -> Result<bool>
pub async fn initialize(&self, _cfg: &Config) -> Result<bool>
Initialize the engine manager and ensure a suitable engine is available
Sourcepub async fn check_suitable_engine(&self) -> Result<bool>
pub async fn check_suitable_engine(&self) -> Result<bool>
Check if we have an engine suitable for current hardware
Sourcepub async fn select_best_engine(&self) -> Result<Option<EngineInfo>>
pub async fn select_best_engine(&self) -> Result<Option<EngineInfo>>
Select and set the best engine for current hardware as default
Sourcepub async fn download_suitable_engine(&self) -> Result<EngineInfo>
pub async fn download_suitable_engine(&self) -> Result<EngineInfo>
Download and install a suitable engine for current hardware
Sourcepub async fn ensure_engine_available(&self) -> Result<bool>
pub async fn ensure_engine_available(&self) -> Result<bool>
Ensures an engine is available, downloading if necessary. This method is designed for automatic recovery scenarios. Returns Ok(true) if engine is available, Ok(false) if download failed.
Sourcepub fn get_hardware_info(&self) -> &HardwareCapabilities
pub fn get_hardware_info(&self) -> &HardwareCapabilities
Get information about current hardware capabilities
Sourcepub async fn refresh_available_engines(&self) -> Result<()>
pub async fn refresh_available_engines(&self) -> Result<()>
Refresh available engines from remote sources
Sourcepub async fn get_status_info(&self) -> String
pub async fn get_status_info(&self) -> String
Get detailed status information about the engine manager
Sourcepub async fn install_engine_by_id(&self, engine_id: &str) -> Result<EngineInfo>
pub async fn install_engine_by_id(&self, engine_id: &str) -> Result<EngineInfo>
Install a specific engine by ID