Database migration system
Structs
- Migration
Manager - Manages database schema migrations
Functions
- get_
database_ stats - Get database statistics from a connection This is safe to call even with a locked connection since it only performs read queries
- get_
database_ stats_ from_ path - Get database statistics with connection creation Useful when you don’t have an existing connection
- run_
maintenance - Run database maintenance tasks