pub fn get_database_stats(conn: &Connection) -> Result<DatabaseStats>Expand description
Get database statistics from a connection This is safe to call even with a locked connection since it only performs read queries
pub fn get_database_stats(conn: &Connection) -> Result<DatabaseStats>Get database statistics from a connection This is safe to call even with a locked connection since it only performs read queries