Thread-based server implementation
This module provides the server startup that uses thread-based shared memory architecture. All API handlers access state through Arc-wrapped shared memory (UnifiedAppState) — zero network hops between components. The only network call is to the localhost llama-server.
Structs
- Thread
Based AppState - Thread-based unified application state (internal, used during initialization)
Functions
- run_
thread_ server - Run server with thread-based architecture