run_thread_server

Function run_thread_server 

pub async fn run_thread_server(
    cfg: Config,
    port_tx: Option<Sender<u16>>,
) -> Result<()>
Run server with thread-based architecture

Arguments

  • cfg - Server configuration
  • port_tx - Optional channel to communicate the selected port back to caller This is used when the configured port is unavailable and a random port is selected